@@ -16,7 +16,7 @@
 if {[info commands package] == ""} {
     error "version mismatch: library\nscripts expect Tcl version 7.5b1 or later but the loaded version is\nonly [info patchlevel]"
 }
-package require -exact Tcl 8.5.17
+package require -exact Tcl 8.6.3
 
 # Compute the auto path to use in this interpreter.
 # The values on the path come from several locations:
@@ -142,11 +142,7 @@ if {(![interp issafe]) && ($tcl_platform(platform) eq "windows")} {
 		}
 	    }
 	    if {![info exists env(COMSPEC)]} {
-		if {$tcl_platform(os) eq "Windows NT"} {
-		    set env(COMSPEC) cmd.exe
-		} else {
-		    set env(COMSPEC) command.com
-		}
+		set env(COMSPEC) cmd.exe
 	    }
 	}
 	InitWinEnv
@@ -218,11 +214,9 @@ if {[namespace which -command tclLog] eq ""} {
 # exist in the interpreter.  It takes the following steps to make the
 # command available:
 #
-#	1. See if the command has the form "namespace inscope ns cmd" and
-#	   if so, concatenate its arguments onto the end and evaluate it.
-#	2. See if the autoload facility can locate the command in a
+#	1. See if the autoload facility can locate the command in a
 #	   Tcl script file.  If so, load it and execute it.
-#	3. If the command was invoked interactively at top-level:
+#	2. If the command was invoked interactively at top-level:
 #	    (a) see if the command exists as an executable UNIX program.
 #		If so, "exec" the command.
 #	    (b) see if the command requests csh-like history substitution
@@ -239,22 +233,14 @@ proc unknown args {
     variable ::tcl::UnknownPending
     global auto_noexec auto_noload env tcl_interactive errorInfo errorCode
 
-    # If the command word has the form "namespace inscope ns cmd"
-    # then concatenate its arguments onto the end and evaluate it.
-
-    set cmd [lindex $args 0]
-    if {[regexp "^:*namespace\[ \t\n\]+inscope" $cmd] && [llength $cmd] == 4} {
-	#return -code error "You need an {*}"
-        set arglist [lrange $args 1 end]
-	set ret [catch {uplevel 1 ::$cmd $arglist} result opts]
-	dict unset opts -errorinfo
-	dict incr opts -level
-	return -options $opts $result
+    if {[info exists errorInfo]} {
+	set savedErrorInfo $errorInfo
+    }
+    if {[info exists errorCode]} {
+	set savedErrorCode $errorCode
     }
 
-    catch {set savedErrorInfo $errorInfo}
-    catch {set savedErrorCode $errorCode}
-    set name $cmd
+    set name [lindex $args 0]
     if {![info exists auto_noload]} {
 	#
 	# Make sure we're not trying to load the same proc twice.
@@ -412,7 +398,8 @@ proc unknown args {
 	    return -code error "ambiguous command name \"$name\": [lsort $cmds]"
 	}
     }
-    return -code error "invalid command name \"$name\""
+    return -code error -errorcode [list TCL LOOKUP COMMAND $name] \
+	"invalid command name \"$name\""
 }
 
 # auto_load --
@@ -835,14 +822,14 @@ proc tcl::CopyDirectory {action src dest} {
 }
 # ACTIVESTATE ACTIVETCL PRODUCT INFO BEGIN -*- tcl -*-
 # Copyright (C) 2001-2008 ActiveState Software Inc
-# Nov 06, 2014
+# Nov 08, 2014
 #
 
 #
-# Extension code to tcl8.5/library/init.tcl declaring the
+# Extension code to tcl8.6/library/init.tcl declaring the
 # version information for ActiveTcl.
 #
-# ActiveState ActiveTcl 8.5.17.0.298612 Linux/x86, Thu Nov 06 13:00:08 PST 2014
+# ActiveState ActiveTcl 8.6.3.0.298612 Linux/x86, Sat Nov 08 14:54:29 PST 2014
 #
 
 namespace eval ::activestate {
@@ -852,13 +839,13 @@ namespace eval ::activestate {
     array set {ActiveTcl} {
 	build         {298612}
 	product       {ActiveTcl}
-	release       {8.5.17.0}
-	tcl,revision  {bd09a69e14fb80cefce4c3b9e223264ad5148bed}
-	tk,revision   {32a43619cdf5e66994859d6597b2de6b61e8d0a0}
+	release       {8.6.3.0}
+	tcl,revision  {b71c2af14abcd17f47089f686b0e932fb2acb85d}
+	tk,revision   {4d3596b492cdae46e24018cc0c5f16abab206ffd}
 	maturity      {final}
 	arch          {linux-ix86}
-	buildtime,sec {1415307608}
-	buildtime,fmt {Thu Nov 06 13:00:08 PST 2014}
+	buildtime,sec {1415487269}
+	buildtime,fmt {Sat Nov 08 14:54:29 PST 2014}
 	as,mode       {normal}
     }
 
@@ -866,16 +853,16 @@ namespace eval ::activestate {
 
     variable  config
     array set config {
-	{ActiveTcl} {ActiveState ActiveTcl 8.5.17.0.298612 Linux/x86 @ Thu Nov 06 13:00:08 PST 2014 bd09a69e14fb80cefce4c3b9e223264ad5148bed / normal}
+	{ActiveTcl} {ActiveState ActiveTcl 8.6.3.0.298612 Linux/x86 @ Sat Nov 08 14:54:29 PST 2014 b71c2af14abcd17f47089f686b0e932fb2acb85d / normal}
     }
 }
 
-package provide {ActiveTcl} {8.5.17.0.298612}
+package provide {ActiveTcl} {8.6.3.0.298612}
 
 # ACTIVESTATE ACTIVETCL PRODUCT INFO END
 # ACTIVESTATE ACTIVETCL SITE CODE BEGIN -*- tcl -*-
 # Copyright (C) 2001-2008 ActiveState Software Inc
-# Nov 06, 2014
+# Nov 08, 2014
 #
 
 # Do not perform file operations which are not available in a safe
