@@ -13,7 +13,6 @@ exec wish "$0" ${1+"$@"}
 package require Tcl	8.5
 package require Tk	8.5
 package require msgcat
-package require Ttk
 
 eval destroy [winfo child .]
 set tk_demoDirectory [file join [pwd] [file dirname [info script]]]
@@ -318,16 +317,13 @@ addFormattedText {
     @@demo image1	Two labels displaying images
     @@demo image2	A simple user interface for viewing images
     @@demo labelframe	Labelled frames
-    @@new
     @@demo ttkbut	The simple Themed Tk widgets
 
     @@subtitle	Listboxes and Trees
     @@demo states	The 50 states
     @@demo colors	Colors: change the color scheme for the application
     @@demo sayings	A collection of famous and infamous sayings
-    @@new
     @@demo mclist	A multi-column list of countries
-    @@new
     @@demo tree		A directory browser tree
 
     @@subtitle	Entries, Spin-boxes and Combo-boxes
@@ -335,7 +331,6 @@ addFormattedText {
     @@demo entry2	Entries with scrollbars
     @@demo entry3	Validated entries and password fields
     @@demo spin		Spin-boxes
-    @@new
     @@demo combo	Combo-boxes
     @@demo form		Simple Rolodex-like form
 
@@ -345,7 +340,6 @@ addFormattedText {
     @@demo bind		Hypertext (tag bindings)
     @@demo twind	A text widget with embedded windows and other features
     @@demo search	A search tool built with a text widget
-    @@new
     @@demo textpeer	Peering text widgets
 
     @@subtitle	Canvases
@@ -356,7 +350,6 @@ addFormattedText {
     @@demo ruler	A ruler with adjustable tab stops
     @@demo floor	A building floor plan
     @@demo cscroll	A simple scrollable canvas
-    @@new
     @@demo knightstour  A Knight's tour of the chess board
 
     @@subtitle	Scales and Progress Bars
@@ -364,38 +357,30 @@ addFormattedText {
     @@demo vscale	Vertical scale
     @@new
     @@demo ttkscale	Themed scale linked to a label with traces
-    @@new
     @@demo ttkprogress	Progress bar
 
     @@subtitle	Paned Windows and Notebooks
     @@demo paned1	Horizontal paned window
     @@demo paned2	Vertical paned window
-    @@new
     @@demo ttkpane	Themed nested panes
-    @@new
     @@demo ttknote	Notebook widget
 
     @@subtitle	Menus and Toolbars
     @@demo menu		Menus and cascades (sub-menus)
     @@demo menubu	Menu-buttons
-    @@new
     @@demo ttkmenu	Themed menu buttons
-    @@new
     @@demo toolbar	Themed toolbar
 
     @@subtitle	Common Dialogs
     @@demo msgbox	Message boxes
     @@demo filebox	File selection dialog
     @@demo clrpick	Color picker
+    @@demo fontchoose	Font selection dialog
 
     @@subtitle	Animation
-    @@new
     @@demo anilabel	Animated labels
-    @@new
     @@demo aniwave	Animated wave
-    @@new
     @@demo pendulum	Pendulum simulation
-    @@new
     @@demo goldberg	A celebration of Rube Goldberg
 
     @@subtitle	Miscellaneous
@@ -724,10 +709,10 @@ proc PrintTextWin32 {filename} {
 proc tkAboutDialog {} {
     tk_messageBox -icon info -type ok -title [mc "About Widget Demo"] \
 	    -message [mc "Tk widget demonstration application"] -detail \
-"[mc {Copyright (c) %s} {1996-1997 Sun Microsystems, Inc.}]
-[mc {Copyright (c) %s} {1997-2000 Ajuba Solutions, Inc.}]
-[mc {Copyright (c) %s} {2001-2007 Donal K. Fellows}]
-[mc {Copyright (c) %s} {2002-2007 Daniel A. Steffen}]"
+"[mc "Copyright \u00a9 %s" {1996-1997 Sun Microsystems, Inc.}]
+[mc "Copyright \u00a9 %s" {1997-2000 Ajuba Solutions, Inc.}]
+[mc "Copyright \u00a9 %s" {2001-2009 Donal K. Fellows}]
+[mc "Copyright \u00a9 %s" {2002-2007 Daniel A. Steffen}]"
 }
 
 # Local Variables:
